@@ -1,5 +1,21 @@
 deepgmm <- function(y, layers, k, r,
-            it = 250, eps = 0.001, init = 'kmeans', init_est = 'factanal') {
+            it = 250, eps = 0.001, init = 'kmeans', init_est = 'factanal',
+            seed = NULL, scale = TRUE) {
+
+  if (any(class(y) %in% 'data.frame'))
+  	y <- as.matrix(y)
+
+  if (!is.null(seed)) {
+
+    if(!is.numeric(seed)) {
+      stop("The value of seed must be an integer")
+    }
+
+    set.seed(seed)
+  }
+
+  if (scale)
+    y <- scale(y)
 
   if (any(tolower(init) %in% c('kmeans', 'k-means', 'k')))
     init <- 'kmeans'
@@ -9,8 +25,7 @@ deepgmm <- function(y, layers, k, r,
     init <- 'hclass'
   if (any(tolower(init_est) == c('factanal', 'factana', 'fact', 'f')))
     init_est <- 'factanal'
-  if (any(class(y) %in% 'data.frame'))
-  	y <- as.matrix(y)
+
 
   # check arguments
   tmp <- valid_args(Y = y, layers = layers, k = k, r = r, it = it,
@@ -22,7 +37,7 @@ deepgmm <- function(y, layers, k, r,
   # Initialing parameters
   lst <- list(w = list(), H = list(), mu = list(), psi = list(),
                                                    psi.inv = list())
-  for (i in 1 : layers) {
+for (i in 1:layers) {
 
     if (i == 1) {
 
@@ -35,6 +50,9 @@ deepgmm <- function(y, layers, k, r,
     # provide initial parititioning of the observations
     s <- initial_clustering(data, k, i, init)
 
+        # provide initial parititioning of the observations
+    s <- initial_clustering(data, k, i, init)
+
     # in case if one of the groups is small
     for  (j in 1 : k[i]) {
       if ((table(s)[j]) < 2) {
@@ -53,7 +71,7 @@ deepgmm <- function(y, layers, k, r,
 
       lst$w[i] <- list(i_lst$w)
       lst$H[i] <- list(i_lst$H)
-      lst$mu[i] <- list(i_lst$mu)
+      lst$mu[i] <- list(i_lst$mu) 
       lst$psi[i] <- list(i_lst$psi)
       lst$psi.inv[i] <- list(i_lst$psi.inv)
       z <- i_lst$z
@@ -92,7 +110,8 @@ deepgmm <- function(y, layers, k, r,
   out$lik <- out$likelihood
   output <- out[c("H", "w", "mu", "psi", "lik", "bic", "aic", "clc",
                   "icl_bic", "s", "h")]
-  output <- c(output, list(k = k, r = r[-1], numobs = numobs, layers = layers))
+  output <- c(output, list(k = k, r = r[-1], numobs = numobs, layers = layers,
+                           seed = seed))
   output$call <- match.call()
   class(output) <- "dgmm"
 
